@@ -394,9 +394,10 @@ def pseudo_3d_vgg_features( inshape = [128,128,128], layer = 4, angle=0, pretrai
     return feature_extractor
 
 def pseudo_3d_vgg_features_unbiased( inshape = [128,128,128], layer = 4 ):
-    feature_extractor0 = pseudo_3d_vgg_features( inshape, layer, angle=0, pretrained=True )
-    feature_extractor1 = pseudo_3d_vgg_features( inshape, layer, angle=1, pretrained=True )
-    feature_extractor2 = pseudo_3d_vgg_features( inshape, layer, angle=2, pretrained=True )
+    f = [
+        pseudo_3d_vgg_features( inshape, layer, angle=0, pretrained=True ),
+        pseudo_3d_vgg_features( inshape, layer, angle=1, pretrained=True ),
+        pseudo_3d_vgg_features( inshape, layer, angle=2, pretrained=True ) ]
     f1=f[0].inputs
     f0o=f[0]( f1 )
     f1o=f[1]( f1 )
